Riskinarvioinnin tekeminen OiRA-työkalulla | OiRA

Aiheet

# Riskinarvioinnin tekeminen OiRA-työkalulla

## Uuden istunnon aloittaminen

Aloita uusi riskinarviointi napsauttamalla linkkiä ”Aloita uusi istunto”.

## Riskinarvioinnin avaaminen

Kun olet aloittanut riskinarvioinnin, voit hakea sen milloin tahansa koontinäytöltä otsikon ”Omat riskiarvioinnit” alta. Sieltä voit myös aloittaa uuden riskinarvioinnin.

Koontinäyttö

## Riskinarviointilomakkeella liikkuminen

Jokaisessa riskinarvioinnissa on useita peräkkäisiä vaiheita. Ne näkyvät päävalikossa näytön vasemmalla puolella:

- Suunnittelu
- Osallistuminen
- Tunnistaminen + Arviointi
- Toimintasuunnitelma
- Raportti
- Tila

Eri riskinarviointivälineiden rakenne voi olla erilainen OiRA-kumppanien / OiRA-työkalun kehittäjien valintojen mukaan. Joissakin välineissä riskien tunnistamis- ja arviointivaiheeseen sisältyy toimintasuunnitelma. Tässä tapauksessa vasemmalla oleva valikko on seuraavanlainen:

- Suunnittelu
- Osallistuminen
- Arviointi
- Raportti
- Tila

## Suunnittelu

Jokainen istunto/arviointityökalu alkaa suunnitteluvaiheella. Siinä riskinarvioinnille annetaan nimi, jonka avulla pystyt myöhemmin erottamaan toisistaan useat työkalulla tekemäsi riskinarvioinnit.

Linkissä ”Lisätietoa tästä työkalusta” on lisätietoa valitusta työkalusta ja sen kehittämiseen osallistuneista osapuolista.

Kun olet napsauttanut ”Aloita”, työkalussa saatetaan esittää joitakin lisäkysymyksiä sen mukaan, mitä työkalua käytät. Tämä valmistautumisnäkymä profiiliin liittyvine kysymyksineen tulee näkyviin vain työkaluissa, joiden osaksi se on määritetty.

Tässä vaiheessa voit

- valita tai ohittaa tilanteita sen mukaan, koskevatko ne liiketoimintaasi. Vastaa asianmukaisissa kohdissa ”Kyllä”.
- luetella useita liiketoimintayksikköjä, haaraliikkeitä tai toimipaikkoja jne. Asiaan liittyvät riskit toistetaan jokaisessa kohdassa.

Profiili-näkymä suunnitteluvaiheessa

Suunnitteluvaihe on erittäin tärkeä, koska siinä määritetään täsmällisesti yrityksesi liiketoiminnan tyyppi ja siihen liittyvät riskit. Kun olet napsauttanut ”Tallenna ja jatka”, sinut ohjataan seuraavaan osioon ”Osallistuminen”.

Huomautus: Monissa työkaluissa ei ole profiiliin liittyviä kysymyksiä, koska niissä ei käytetä tätä toimintoa kysymysten kohdentamiseen. Siinä tapauksessa tämä näkymä ohitetaan automaattisesti.

## Osallistuminen

Tämä vaihe muistuttaa työntekijöiden osallistumisen merkityksestä, ja siinä esitellään eri tapoja varmistaa työntekijöiden osallistumisen onnistuminen. Tästä voit ladata tai tulostaa riskiarvioinnin sisällön jaettavaksi työntekijöillesi. Näin varmistetaan, että työntekijät pystyvät osallistumaan työpaikkansa tilanteen arviointiin.

## Arviointi

Tässä vaiheessa määritetään yrityksesi kannalta merkittävät vaarat ja ongelmat.

Huomautus: Tähän näkymään on voitu yhdistää vaihe ”Toimintasuunnitelma” (ks. jäljempänä), mikäli OiRA-kumppani on määrittänyt työkalun niin. Siinä tapauksessa vaihe on nimeltään ”Arviointi”, ja kohdassa ”Toimintasuunnitelma” kuvatut osat näytetään kunkin riskitekijän määrittämisen ja arvioinnin kohdalla.

Tunnistaminen ja arviointi

Näytön vasemmassa reunassa kohdan ”Tunnistaminen + Arviointi” / ”Arviointi” alla näytetään kaikki työkaluun sisältyvät aiheet/moduulit. Korostettuna on aihe, jota parhaillaan tarkastelet.

### Tunnistaminen

Kunkin riskin osalta on arvioitava, pitävätkö toivottua tilaa kuvaavat väittämät paikkansa yrityksesi osalta. Vastausvaihtoehdot ovat seuraavat:

- Kyllä: jos vastaat väittämään ”kyllä”, muita toimia ei tarvita, koska olet arvioinut, ettei riskiä ole.
- Ei: jos vastaat väittämään ”ei”, tarvitaan jatkotoimia. Sinua pyydetään valitsemaan erityisiä toimenpiteitä.
- Ei sovelleta: joissakin riskinarvioinneissa voi vastata ”ei sovelleta”, jos riski ei ole merkityksellinen yritykseksi kannalta.

Kunkin väittämän jälkeen on tavallisesti lisätietoa nimenomaisesta riskistä:

- Tiedot: lyhyt kuvaus, jonka tukena on joskus kuvia ja jossa annetaan lisätietoa riskistä.
- Resurssit: lisätietoa riskistä, kuten lainsäädäntöön ja sääntelyyn liittyviä viitteitä. Joskus tähän kohtaan voidaan liittää myös asiakirjoja luettavaksi.
- Huomautukset: tähän voit kirjoittaa omia huomautuksia, jotka näkyvät raportissa arvioinnin päätteeksi.

Kun olet vastannut riskejä koskeviin väittämiin ja siirtynyt seuraavaan kohtaan, vasemmalla olevaan valikkoon päivittyy värillinen symboli, joka ilmaisee, oletko

- vastannut myönteisesti (vihreä merkki)
- vastannut kielteisesti (punainen rasti)
- lykännyt vastaamista (oranssi kysymysmerkki)

Vastaamattomissa kysymyksissä näytetään harmaa symboli.

### Arviointi

Tässä vaiheessa arvioidaan tunnistettujen riskitekijöiden tärkeysjärjestys.

Riskin arviointi

Huomautus: Joissakin OiRA-työkaluissa arviointia ei näytetä. Tämä riippuu siitä, miten kansallinen kumppani / OiRA-työkalun kehittäjä on määrittänyt kyseisen OiRA-työkalun.

Jos olet tunnistusvaiheessa määrittänyt riskin olevan olemassa (merkitty punaisella rastilla), näkyviin tulee arviointiosio. Kutakin riskiä koskevan arviointimenetelmän mukaan sinua pyydetään

- arvioimaan merkitys: korkea, kohtalainen tai vähäinen

Riskien tärkeysjärjestyksen määrittäminen

TAI

- vastaamaan muutamaan kysymykseen riskin toistuvuudesta, vakavuudesta ja todennäköisyydestä, jotta merkitys voidaan laskea vastausten perusteella.

Riskejä koskevien muuttujien määrittäminen

### Toimialalle määritetyt tärkeimmät riskit:

OiRA-työkalun luonut kansallinen kumppani / OiRA-työkalun kehittäjä katsoo jotkin työkalukohtaiset riskit erittäin tärkeiksi. Sinua ei pyydetä arvioimaan tällaisia tärkeäksi määritettyjä riskejä, koska niiden tärkeydeksi asetetaan automaattisesti ”korkea”.

Tärkeimmät riskit

### Omat riskitekijät

Kun olet vastannut kaikkiin riskejä koskeviin aiheisiin kohdassa ”Tunnistaminen + Arviointi” / ”Arviointi”, pääset vapaaehtoiseen kohtaan ”Muut riskitekijät”. Voit luoda omia merkintöjä painikkeesta ”Lisää riski”.

Jos työkalussa ei ole mainittu riskejä, joita työpaikallasi/yrityksessäsi esiintyy, ne on lisättävä tähän kohtaan. Voit määrittää/muotoilla nämä riskit kokonaan itse.

Omat riskitekijät

Omien riskitekijöiden lisääminen toimii hyvin samalla tavalla kuin OiRA-työkaluun sisältyvät riskit, mutta sinun on tietysti kirjoitettava itse riskiä kuvaava teksti. Tekstin pitäisi vähintään olla lyhyt väittämä, jossa kuvataan ongelmatilanne. Sen voi myös kuvata pidemmin. Voit myös ladata kuvan tietyn tilanteen havainnollistamiseksi.

Tavanomaisten riskien tapaan on ilmoitettava, onko riski olemassa vai ei. Näin voit poistaa itse lisäämäsi riskitekijät käsittelystä heti, kun ne on onnistuneesti hoidettu, mutta pitää ne kuitenkin mukana riskinarvioinnissa dokumentointitarkoituksia varten.

Voit lisätä niin monta riskitekijää kuin on tarpeen.

Lisää oma riskitekijä

## Toimintasuunnitelma

Tässä vaiheessa valitaan toimenpiteet, jotka haluat toteuttaa aiemmin määrittämiesi riskien poistamiseksi tai niiden lieventämiseksi.

Huomautus: Kuten edellä on mainittu, toimintasuunnitelma esitetään erillisenä vaiheena vasemmalla olevassa valikossa tai se näytetään kunkin tunnistetun riskitekijän kohdalla. Viimeksi mainitussa tapauksessa valikon vaiheen nimi on ”Arviointi”, ja siihen sisältyvät sekä riskiväittämät että vastausten valinta.

Sinulle tarjottu versio riippuu kansallisen OiRA-kumppanin / OiRA-työkalun kehittäjän valinnoista.

### Integroitu toimintasuunnitelma

Integroitu toimintasuunnitelma

Jos vastaat kysymykseen ”ei”, sivulle avautuu toimintasuunnitelmamoduuli otsikon ”Toimenpiteet” alla.

Voit sekä valita järjestelmän ehdottamien toimenpiteiden luettelosta että määrittää omia toimenpiteitä.

### Erillinen toimintasuunnitelma

Kun toimintasuunnitelma näytetään erillisenä vaiheena, siihen pääsee vasemmalla puolella olevasta navigointipalkista.

Aloita suunnitelma napsauttamalla painiketta ”Luo toimintasuunnitelma”.

Toimintasuunnitelmavaiheessa vasemmalla olevassa valikossa näytetään nyt vain jatkotoimia varten merkityt riskit. Muita riskejä ei edellisessä vaiheessa merkitty olevan.

Sinua pyydetään määrittämään toimenpiteet kaikille riskeille, joiden osalta vastasit ”ei” arviointiprosessissa, ja tärkeäksi määritetyille riskeille (riippumatta siitä, vastasitko niiden osalta myönteisesti vai kielteisesti).

Riskitekijät toimintasuunnitelmassa

Voit valita toimia joko järjestelmän ehdottamien toimenpiteiden luettelosta tai määrittää omia toimenpiteitä.

#### Lisää oma toimenpide

Lisätoimenpiteen lisääminen

Aloita ehkäisevän toimenpiteen määrittäminen painamalla painiketta ”Lisää toimenpide”. Sinun on

- kuvattava yleinen toimintamalli, jota käytetään riskin poistamiseen tai vähentämiseen
- halutessasi ilmoitettava tarvittavan asiantuntemuksen taso ja/tai vaatimukset (voit esimerkiksi kertoa tässä, jos tämän riskin hallitsemiseen tarvitaan erityistä koulutusta tai ulkopuolista asiantuntemusta)
- annettava tietoa siitä, kuka vastaa täytäntöönpanosta
- määritettävä tarvittaessa budjetti
- määritettävä päivämäärä, jolloin toimenpiteen toteuttaminen alkaa, ja päivämäärä, milloin sen on määrä loppua (valinnainen kohta).

Voit lisätä niin monta toimenpidettä kuin on tarpeen.

#### Lisää tunnettuja yleisiä toimenpiteitä

Yksittäisiä riskejä varten on käytössä ennalta määritettyjä toimenpiteitä sen mukaan, miten OiRA-kumppani / OiRA-työkalun kehittäjä on määrittänyt työkalun. Voit valita yhden tai useamman ennalta määritetyn toimenpiteen painikkeesta ”Valitse toimenpiteet”.

Näkyviin tulee ponnahdusvalikko, jossa on kaikki ehdotetut toimenpiteet. Napsauta ”Lisää”-painiketta niiden kohdalla, joita haluat käyttää.

Tämän jälkeen nämä ennalta määritetyt toimenpiteet luetellaan toimintasuunnitelmassasi. Kuvaus tehtävästä on vakionmuotoinen, mutta voit täyttää muita kenttiä (vastuuhenkilö, budjetti, päivämäärät), ja niiden täyttämistä myös suositellaan.

Tunnettujen yleisten toimenpiteiden lisääminen

Sekä tunnetut yleiset toimenpiteet että itse määrittämäsi toimenpiteet voidaan poistaa milloin tahansa.

## Raportti

Toimintasuunnitelman viimeistelyn jälkeen siitä voi tuottaa raportin.

Jos haluat lisätä huomautuksen liitettäväksi raporttiin, kirjoita teksti sille tarkoitettuun laatikkoon ja tallenna se.

Kommenttien lisääminen raporttiin

Täällä on lisätietoa eri raporteista ja niiden käytöstä.

## Tila

Pieni ympyräkaavio vasemmalla olevassa valikossa näyttää etenemisesi työkalussa.

Tilaa koskevasta osiosta saa yleisnäkymän siitä, miten monta riskitekijää olet määrittänyt, miten monta niistä olet käsitellyt valitsemalla toimenpiteitä ja miten moneen riski-/väittämäkohtaan et ole vielä vastannut.

Tilasivu

Tilanäkymästä näet, miten pitkälle olet kussakin moduulissa edennyt. Se voi auttaa huomaamaan, missä osioissa riskejä on edelleen arvioitavana tai missä on määritettävä toimenpiteitä tunnistetuille riskeille.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More